==> haskell-vector-space-0.16-139-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-space.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-space
version:              0.16
visibility:           public
id:                   vector-space-0.16-7aXUzPk6ndZ9zri3XmzbfI
key:                  vector-space-0.16-7aXUzPk6ndZ9zri3XmzbfI
license:              BSD-3-Clause
copyright:            (c) 2008-2012 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott 
stability:            experimental
synopsis:             Vector & affine spaces, linear maps, and derivatives
description:
    /vector-space/ provides classes and generic operations for vector
    spaces and affine spaces.  It also defines a type of infinite towers
    of generalized derivatives.  A generalized derivative is a linear
    transformation rather than one of the common concrete representations
    (scalars, vectors, matrices, ...).

    /Warning/: this package depends on type families working fairly well,
    requiring GHC version at least 6.9.

    Project wiki page: <http://haskell.org/haskellwiki/vector-space>

    &#169; 2008-2012 by Conal Elliott; BSD3 license.

category:             math
abi:                  67fb6c9020763bb8f35dd567224a133a
exposed:              True
exposed-modules:
    Data.AdditiveGroup Data.AffineSpace Data.Basis Data.Cross
    Data.Derivative Data.LinearMap Data.Maclaurin Data.VectorSpace

hidden-modules:       Data.VectorSpace.Generic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-space-0.16
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-space-0.16
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-space-0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-space
hs-libraries:         HSvector-space-0.16-7aXUzPk6ndZ9zri3XmzbfI
depends:
    Boolean-0.2.4-LIaGyLXCKND29bUBbSsJWj
    MemoTrie-0.6.11-LEENIez5UjiC8X1hN8lkz6
    NumInstances-1.4-4OncN3WniO73xybRJJuGAa base-4.17.2.1

haddock-interfaces:
    /usr/share/doc/haskell-vector-space/html/vector-space.haddock

haddock-html:         /usr/share/doc/haskell-vector-space/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-space-0.16-140-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-space.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-space
version:              0.16
visibility:           public
id:                   vector-space-0.16-4rYzCviDMBZIkAuGXWtuaP
key:                  vector-space-0.16-4rYzCviDMBZIkAuGXWtuaP
license:              BSD-3-Clause
copyright:            (c) 2008-2012 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott 
stability:            experimental
synopsis:             Vector & affine spaces, linear maps, and derivatives
description:
    /vector-space/ provides classes and generic operations for vector
    spaces and affine spaces.  It also defines a type of infinite towers
    of generalized derivatives.  A generalized derivative is a linear
    transformation rather than one of the common concrete representations
    (scalars, vectors, matrices, ...).

    /Warning/: this package depends on type families working fairly well,
    requiring GHC version at least 6.9.

    Project wiki page: <http://haskell.org/haskellwiki/vector-space>

    &#169; 2008-2012 by Conal Elliott; BSD3 license.

category:             math
abi:                  6a175ce5ab9dff7b2aa4f2f036c4ec91
exposed:              True
exposed-modules:
    Data.AdditiveGroup Data.AffineSpace Data.Basis Data.Cross
    Data.Derivative Data.LinearMap Data.Maclaurin Data.VectorSpace

hidden-modules:       Data.VectorSpace.Generic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-space-0.16
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-space-0.16
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-space-0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-space
hs-libraries:         HSvector-space-0.16-4rYzCviDMBZIkAuGXWtuaP
depends:
    Boolean-0.2.4-LIaGyLXCKND29bUBbSsJWj
    MemoTrie-0.6.11-4M98ElhGKj7I3zDiyRDooP
    NumInstances-1.4-4OncN3WniO73xybRJJuGAa base-4.17.2.1

haddock-interfaces:
    /usr/share/doc/haskell-vector-space/html/vector-space.haddock

haddock-html:         /usr/share/doc/haskell-vector-space/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
